GpuFrameTimings class final
Every labelled pass of one frame, in the order they were submitted.
Constructors
-
GpuFrameTimings({required int frame, required List<
GpuPassTiming> passes}) -
const
Properties
- frame → int
-
Which frame, counted by
GraphicsDevice.beginFramefrom the first.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
passes
→ List<
GpuPassTiming> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited