PassStateApply extension
Applies a PassState to an encoder.
- on
Methods
-
setState(
PassState state) → void -
Available on PassEncoder, provided by the PassStateApply extension
Emits one call per fieldstatesets, and nothing for the rest.
Applies a PassState to an encoder.
Available on PassEncoder, provided by the PassStateApply extension
Emits one call per fieldstate sets, and nothing for the rest.