maxAnisotropy property

  1. @override
int maxAnisotropy
final

Sixteen, which is what most hardware answers, and settable so a test can be the device that answers one and see what a caller clamps to.

Implementation

@override
final int maxAnisotropy;