unsupportedFormats property

Set<TextureFormat> unsupportedFormats
final

The formats this fake says it cannot sample, so a test can be the device that has no BC7 and see what a loader does about it.

Implementation

final Set<TextureFormat> unsupportedFormats;