uploads property
Recorded with its usage, because a backend exists that cannot change its mind about one later.
Implementation
final List<GeometryUsage> uploads = <GeometryUsage>[];
Recorded with its usage, because a backend exists that cannot change its mind about one later.
final List<GeometryUsage> uploads = <GeometryUsage>[];