stageBindings property
Stage name to what it declares, or null to accept every bind.
Implementation
final Map<String, StageBindings>? stageBindings;
Stage name to what it declares, or null to accept every bind.
final Map<String, StageBindings>? stageBindings;