RecordedStencil class final

A stencil configuration, with the back face only when one was named.

Inheritance

Constructors

RecordedStencil(StencilState front, StencilState? back)
const

Properties

back StencilState?
final
front StencilState
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited