RecordedUniformBlock class final

Inheritance

Constructors

RecordedUniformBlock(ShaderHandle shader, String block, Map<String, Float32List> members)
const

Properties

block String
final
hashCode int
The hash code for this object.
no setterinherited
members Map<String, Float32List>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shader ShaderHandle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited