supportsCompute property
Whether compute pipelines can be created and dispatched — H6. The
members below it throw an UnsupportedError where this is false.
Implementation
@override
bool get supportsCompute => inner.supportsCompute;
Whether compute pipelines can be created and dispatched — H6. The
members below it throw an UnsupportedError where this is false.
@override
bool get supportsCompute => inner.supportsCompute;