formatVersion constant
int
const formatVersion
Bumped when an event's fields change meaning, not when one is added.
Implementation
static const int formatVersion = 1;
Bumped when an event's fields change meaning, not when one is added.
static const int formatVersion = 1;