TraceBeginRenderPass class final

Inheritance

Constructors

TraceBeginRenderPass({required int pass, required List<TraceColorTarget> colors, TraceDepthTarget? depth, String? label})
const

Properties

colors → List<TraceColorTarget>
final
depth → TraceDepthTarget?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String
The event's name in a trace file.
no setteroverride
label → String?
final
pass → int
Numbered in the order passes were opened; every pass event names it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited