TraceBindIndexData class final

Inheritance

Constructors

TraceBindIndexData({required int pass, required ByteData bytes, required IndexType type, required int indexCount})
const

Properties

bytes → ByteData
final
hashCode → int
The hash code for this object.
no setterinherited
indexCount → int
final
kind → String
The event's name in a trace file.
no setteroverride
pass → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → IndexType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited