TraceBindUniformBlock class final

Inheritance

Constructors

TraceBindUniformBlock({required int pass, required String shader, required String block, required Map<String, Float32List> members})
const

Properties

block → String
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String
The event's name in a trace file.
no setteroverride
members → Map<String, Float32List>
Copied when recorded: the renderer refills its scratch arrays for the next draw, and a reference would record the last draw's values for all.
final
pass → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shader → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited