members property

Map<String, Float32List> members
final

Copied when recorded: the renderer refills its scratch arrays for the next draw, and a reference would record the last draw's values for all.

Implementation

final Map<String, Float32List> members;