TraceComputeBindStorageBuffer class final

Inheritance

Constructors

TraceComputeBindStorageBuffer({required int pass, required String shader, required String name, required int buffer})
const

Properties

buffer → int
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String
The event's name in a trace file.
no setteroverride
name → String
final
pass → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shader → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited