TraceCreateCubeTextureFromPixels class final

Inheritance

Constructors

TraceCreateCubeTextureFromPixels({required int id, required int size, required TextureFormat format, required List<ByteData> faces, List<List<ByteData>>? mipLevels})
const

Properties

faces → List<ByteData>
final
format → TextureFormat
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
kind → String
The event's name in a trace file.
no setteroverride
mipLevels → List<List<ByteData>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited