TraceCreatePipeline class final
- Inheritance
-
- Object
- TraceEvent
- TraceCreatePipeline
Constructors
- TraceCreatePipeline({required int id, required String vertex, required String fragment, VertexLayoutSpec? layout})
-
const
Properties
- fragment → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- kind → String
-
The event's name in a trace file.
no setteroverride
- layout → VertexLayoutSpec?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vertex → String
-
Stage names, looked up again on the device a trace is replayed on.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
TraceBlobWriter blob) → Map< String, Object?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited