TraceCreateTextureFromPixels class final

Inheritance

Constructors

TraceCreateTextureFromPixels({required int id, required int width, required int height, required TextureFormat format, required ByteData pixels, List<ByteData>? mipLevels})
const

Properties

format → TextureFormat
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
id → int
final
kind → String
The event's name in a trace file.
no setteroverride
mipLevels → List<ByteData>?
final
pixels → ByteData
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited