TraceReleaseTexture class final

Inheritance

Constructors

TraceReleaseTexture(int texture)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → String
The event's name in a trace file.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(TraceBlobWriter blob) → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited