slot property
Which vertex buffer slot this filled. Zero for every draw in the engine except an instanced one, which is what makes a non-zero value worth asserting on.
Implementation
final int slot;
Which vertex buffer slot this filled. Zero for every draw in the engine except an instanced one, which is what makes a non-zero value worth asserting on.
final int slot;